<?php

namespace Drupal\azure_oauth_sso;

/**
 * Provides base OAuth functionality.
 */
trait BaseOAuth {
  /**
   * The configuration object.
   *
   * @var \Drupal\Core\Config\Config
   */
  protected $config;

  /**
   * The language manager.
   *
   * @var \Drupal\Core\Language\LanguageManagerInterface
   */
  protected $language;

  /**
   * The host URL.
   *
   * @var string
   */
  protected $host;

  /**
   * The redirect URI.
   *
   * @var string
   */
  protected $redirectUri;

  /**
   * Retrieves the client ID from configuration.
   *
   * @return string
   *   The client ID.
   */
  protected function getClientId() {
    $this->config = \Drupal::config('azure_oauth_sso_config.settings');
    return $this->config->get('client_id');
  }

  /**
   * Retrieves the AD tenant from configuration.
   *
   * @return string
   *   The AD tenant.
   */
  protected function getAdTenant() {
    $this->config = \Drupal::config('azure_oauth_sso_config.settings');
    return $this->config->get('ad_tenant');
  }

  /**
   * Retrieves the client secret from configuration.
   *
   * @return string
   *   The client secret.
   */
  protected function getClientSecret() {
    $this->config = \Drupal::config('azure_oauth_sso_config.settings');
    return $this->config->get('client_secret');
  }

  /**
   * Retrieves the redirect URI based on current language and host.
   *
   * @return string
   *   The redirect URI.
   */
  protected function getRedirectUri() {
    $this->language = \Drupal::languageManager()->getCurrentLanguage()->getId();
    $this->host = \Drupal::requestStack()->getCurrentRequest()->getSchemeAndHttpHost();
    $this->redirectUri = $this->host . '/' . $this->language . '/oauth/login';
    return $this->redirectUri;
  }

}
